Learn R Programming

RGraphSpace (version 1.5.2)

getGraphSpace,GraphSpace-method: Accessors for fetching slots from a GraphSpace object

Description

getGraphSpace retrieves information from individual slots available in a GraphSpace object.

Usage

# S4 method for GraphSpace
getGraphSpace(gs, what = "graph")

Value

Content from slots in the GraphSpace object.

Arguments

gs

A preprocessed GraphSpace class object

what

A single character value specifying which slot to retrieve from a 'GraphSpace' object. Options: "graph", "nodes", "edges", "pars", "misc", "image", "canvas", "fdata", "coords", and "uuid".

Examples

Run this code
library(RGraphSpace)
library(igraph)

# Load a demo igraph
data('gtoy1', package = 'RGraphSpace')

# Create a new GraphSpace object
gs <- GraphSpace(gtoy1)

# Get the 'graph' slot in gs
getGraphSpace(gs, what = 'graph')

Run the code above in your browser using DataLab