- gs
Either an igraph or GraphSpace class object.
If gs is an igraph, then it must include x, y,
and name vertex attributes (see GraphSpace).
- theme
Name of a custom RGraphSpace theme. These themes
(from 'th0' to 'th3') consist of preconfigured ggplot settings,
which can be subsequently refine using theme.
- xlab
The title for the 'x' axis of a 2D-image space.
- ylab
The title for the 'y' axis of a 2D-image space.
- node.labels
Optional specification of node labels to display.
If FALSE (default), no labels are shown. If TRUE, labels are
displayed for all nodes. Otherwise, a character vector may be supplied
to display labels only for the specified nodes. Character values are matched
against the nodeLabel attribute.
- label.size
Font size passed to geom_text.
- label.color
Color passed to geom_text.
- add.image
A logical value indicating whether to add a background
image, when one is available (see GraphSpace).
- raster
A logical value indicating whether to rasterize the main plot.
See rasterise for further specifications.
- dpi
Raster resolution, in dots per inch.
- dev
Device used in the rasterise call.
- add.labels
Deprecated. Use node.labels instead.
- font.size
Deprecated. Use theme customization instead.
- bg.color
Deprecated. Use theme customization instead.
- ...
Additional arguments passed to the
plotGraphSpace function.