| GeomEdgeSpace | R Documentation |
GeomEdgeSpace is the underlying ggproto object
used by geom_edgespace to draw edge elements in a graph layout.
This geom is designed for network diagrams, where graph attributes are often already in their final form (e.g., hex colors).
GeomEdgeSpace
GeomEdgeSpace understands ggplot2's conventions for segment-like geoms.
geom_edgespace, geom_segment
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.