Skip to contents

GeomEdgeSpace is the underlying ggproto object used by geom_edgespace to draw edge elements in a graph layout.

This geom is designed for network diagrams, where graph attributes are often already in their final form (e.g., hex colors).

Usage

GeomEdgeSpace

Format

An object of class GeomEdgeSpace (inherits from GeomSegment, Geom, ggproto, gg) of length 7.

Aesthetics

GeomEdgeSpace understands ggplot2's conventions for segment-like geoms.