powered by
GeomEdgeSpace is the underlying ggproto object used by geom_edgespace to draw edge elements in a graph layout.
GeomEdgeSpace
This geom is designed for network diagrams, where graph attributes are often already in their final form (e.g., hex colors).
GeomEdgeSpace understands ggplot2's conventions for segment-like geoms.
geom_edgespace, geom_segment