`GeomEdgeSpace` is the underlying ggproto object used by
geom_edgespace to draw edge elements in a 2D graph layout,
whose properties are controlled by aesthetics such as `colour`
and `linewidth`.
This `geom` is designed for graph/network diagrams, where edge attributes are often already in their final form (e.g., hex colors). When used with identity scales, the appearance of edges can be fully controlled by the input data.
GeomEdgeSpaceAn object of class GeomEdgeSpace (inherits from Geom, ggproto, gg) of length 5.
`GeomEdgeSpace` understands the following aesthetics:
`x` Starting horizontal position in
`npc` unit (required).
`y` Starting vertical position in
`npc` unit (required).
`xend` Ending horizontal position in
`npc` unit (required).
`yend` Ending vertical position in
`npc` unit (required).
`colour` Edge colour.
`linewidth` Edge width, using 'lwd' standard graphics unit
(see gpar).
`linetype` Line type, using 'lty' standard graphics unit
(see gpar).
`alpha` Transparency applied to the edge colour.
These aesthetics follow ggplot2's conventions for segment-like `geoms`.
geom_edgespace, geom_segment