Skip to contents

GeomGraphSpace is the underlying ggproto object used by geom_graphspace to draw node and edge elements in a graph layout.

This geom is designed for network diagrams, where graph attributes are often already in their final form (e.g., hex colors).

Usage

GeomGraphSpace

Format

An object of class GeomGraphSpace (inherits from Geom, ggproto, gg) of length 6.

Aesthetics

GeomGraphSpace understands ggplot2's conventions for point-like geoms.