GeomGraphSpace: a ggplot2 prototype for GraphSpace-class methods
Source:R/geom-graphspace.R
GeomGraphSpace.RdGeomGraphSpace is the underlying ggproto object
used by geom_graphspace to draw node and edge elements in a
graph layout.
This geom is designed for network diagrams, where graph attributes are often already in their final form (e.g., hex colors).