| GeomNodeSpace | R Documentation |
GeomNodeSpace is the underlying ggproto object
used by geom_nodespace to draw node elements in a graph layout.
This geom is designed for network diagrams, where graph attributes are often already in their final form (e.g., hex colors).
GeomNodeSpace
GeomNodeSpace understands ggplot2's conventions for point-like geoms.
geom_nodespace, geom_point
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.