Skip to contents

GeomNodeSpace is the underlying ggproto object used by geom_nodespace to draw node elements in a graph layout.

This geom is designed for network diagrams, where graph attributes are often already in their final form (e.g., hex colors).

Usage

GeomNodeSpace

Format

An object of class GeomNodeSpace (inherits from GeomPoint, Geom, ggproto, gg) of length 6.

Aesthetics

GeomNodeSpace understands ggplot2's conventions for point-like geoms.