powered by
GeomNodeSpace is the underlying ggproto object used by geom_nodespace to draw node elements in a graph layout.
GeomNodeSpace
This geom is designed for network diagrams, where graph attributes are often already in their final form (e.g., hex colors).
GeomNodeSpace understands ggplot2's conventions for point-like geoms.
geom_nodespace, geom_point