| names,GraphSpace-method | R Documentation |
Access and modify individual components of a GraphSpace object. Selected igraph methods are applied to the internal graph representation and propagated to downstream node and edge components.
## S4 method for signature 'GraphSpace'
names(x)
## S4 method for signature 'GraphSpace'
gs_names(x)
## S4 method for signature 'GraphSpace'
gs_nodes(x, ...)
## S4 method for signature 'GraphSpace'
gs_edges(x)
## S4 method for signature 'GraphSpace'
gs_image(x)
## S4 replacement method for signature 'GraphSpace'
gs_image(x) <- value
## S4 method for signature 'GraphSpace'
gs_graph(x)
## S4 method for signature 'GraphSpace'
gs_fdata(x)
## S4 replacement method for signature 'GraphSpace'
gs_fdata(x) <- value
## S4 method for signature 'GraphSpace'
gs_nfeatures(x)
## S4 method for signature 'GraphSpace'
gs_features(x)
## S4 method for signature 'GraphSpace'
gs_vcount(x)
## S4 method for signature 'GraphSpace'
gs_ecount(x)
## S4 method for signature 'GraphSpace'
gs_vertex_attr(x, name, ...)
## S4 replacement method for signature 'GraphSpace'
gs_vertex_attr(x, name, ...) <- value
## S4 method for signature 'GraphSpace'
gs_edge_attr(x, name, ...)
## S4 replacement method for signature 'GraphSpace'
gs_edge_attr(x, name, ...) <- value
## S4 method for signature 'GraphSpace'
x$name
## S4 replacement method for signature 'GraphSpace'
x$name <- value
## S3 method for class 'GraphSpace'
as.igraph(x, ...)
x |
A GraphSpace class object |
... |
Additional arguments passed to extraction methods. |
value |
Replacement value for the selected slot or attribute. |
name |
Name of the attribute. |
For gs_nodes(), the optional vars argument specifies
node-associated features retrieved from the fdata
container. See also gs_fetch_features.
Updated GraphSpace object.
vertex_attr, edge_attr,
gs_fetch_features
library(RGraphSpace)
library(igraph)
# Load a demo igraph
data('gtoy1', package = 'RGraphSpace')
# Create a new GraphSpace object
gs <- GraphSpace(gtoy1)
#--- Usage of GraphSpace attribute accessors:
# Vertex names
names(gs)
# Vertex attribute names
gs_names(gs)
# Get a data frame with nodes
gs_nodes(gs)
# Get a data frame with edges
gs_edges(gs)
# Get vertex count
gs_vcount(gs)
# Get edge count
gs_ecount(gs)
# Access all vertex attributes
gs_vertex_attr(gs)
# Access a specific vertex attribute
gs_vertex_attr(gs, "nodeLabel")
# Modify a single value within a vertex attribute
gs_vertex_attr(gs, "nodeSize")["n1"] <- 10
# Replace an entire vertex attribute
gs_vertex_attr(gs, "nodeSize") <- 10
# Alternative syntax using `$` accessor
gs_vertex_attr(gs)$nodeSize <- 10
# Access a specific edge attribute
gs_edge_attr(gs, "edgeLineColor")
# Replace an entire edge attribute
gs_edge_attr(gs, "edgeLineWidth") <- 1
# Alternative syntax using `$` for edge attributes
gs_edge_attr(gs)$edgeLineWidth <- 3
# Add an image and rescale graph coordinates to image space
# Images may be provided as a raster or numeric matrix
gs_image(gs) <- as_colorraster(volcano)
gs <- normalizeGraphSpace(gs)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.