Learn R Programming

RGraphSpace (version 1.5.2)

GraphSpace-accessors: Accessors and attribute utilities for GraphSpace objects

Description

Access and modify individual components of a GraphSpace object. Selected igraph methods are applied to the internal graph representation and propagated to downstream node and edge components.

Usage

# S4 method for GraphSpace
names(x)

# S4 method for GraphSpace gs_names(x)

# S4 method for GraphSpace gs_nodes(x, ...)

# S4 method for GraphSpace gs_edges(x, ...)

# S4 method for GraphSpace gs_image(x)

# S4 method for GraphSpace gs_image(x) <- value

# S4 method for GraphSpace gs_graph(x)

# S4 method for GraphSpace gs_fdata(x)

# S4 method for GraphSpace gs_fdata(x) <- value

# S4 method for GraphSpace gs_nfeatures(x)

# S4 method for GraphSpace gs_features(x)

# S3 method for GraphSpace as.igraph(x, ...)

# S4 method for GraphSpace gs_vcount(x)

# S4 method for GraphSpace gs_ecount(x)

# S4 method for GraphSpace gs_vertex_attr(x, name, ..., value)

# S4 method for GraphSpace gs_vertex_attr(x, name, ...) <- value

# S4 method for GraphSpace gs_delete_v_attr(x, name)

# S4 method for GraphSpace gs_delete_e_attr(x, name)

# S4 method for GraphSpace gs_edge_attr(x, name, ..., value)

# S4 method for GraphSpace gs_edge_attr(x, name, ...) <- value

# S4 method for GraphSpace gs_scale_factor(x)

# S4 method for GraphSpace gs_scale_factor(x) <- value

# S4 method for GraphSpace gs_geometry(x, name = "geometry")

# S4 method for GraphSpace gs_geometry(x, name = "geometry") <- value

# S4 method for GraphSpace $(x, name)

# S4 method for GraphSpace $(x, name) <- value

Value

Updated GraphSpace object.

Arguments

x

A GraphSpace class object

...

Additional arguments passed to extraction methods.

value

Replacement value for the selected slot or attribute.

name

Name of the attribute.

Details

For gs_nodes(), the optional vars argument specifies node-associated features retrieved from the fdata container. See also gs_fetch_features.

See Also

vertex_attr, edge_attr, gs_fetch_features

Examples

Run this code
library(RGraphSpace)
library(igraph)

# Load a demo igraph
data('gtoy1', package = 'RGraphSpace')

# Create a new GraphSpace object
gs <- GraphSpace(gtoy1)

#--- Usage of GraphSpace attribute accessors:

# Vertex names
names(gs)

# Vertex attribute names
gs_names(gs)

# Get a data frame with nodes
gs_nodes(gs)

# Get a data frame with edges
gs_edges(gs)

# Get vertex count
gs_vcount(gs)

# Get edge count
gs_ecount(gs)

# Access all vertex attributes
gs_vertex_attr(gs)

# Access a specific vertex attribute
gs_vertex_attr(gs, "nodeLabel")

# Modify a single value within a vertex attribute
gs_vertex_attr(gs, "nodeSize")["n1"] <- 10

# Replace an entire vertex attribute
gs_vertex_attr(gs, "nodeSize") <- 10

# Access a specific edge attribute
gs_edge_attr(gs, "edgeColor")

# Replace an entire edge attribute
gs_edge_attr(gs, "edgeLineWidth") <- 1

# Add an image and rescale graph coordinates to image space
# Images may be provided as a raster or numeric matrix
gs_image(gs) <- as_colorraster(volcano)
gs <- normalizeGraphSpace(gs, image.space = FALSE)

# apply a scaling factor to node coordinates
gs_scale_factor(gs) <- 0.1
# undo scaling 
gs_scale_factor(gs) <- 1

# add an 'sfc' geometry column
pts <- replicate(gs_vcount(gs), sf::st_point(runif(2)), simplify = FALSE)
gs_geometry(gs) <- sf::st_sfc(pts)

Run the code above in your browser using DataLab