| RGraphSpace-package | R Documentation |
An interface to integrate 'igraph' and 'ggplot2' graphics within a normalized coordinate system. 'RGraphSpace' extends 'ggplot2' with graph-aware geometries optimized for large networks. The 'GraphSpace' class integrates directly with 'ggplot2' through specialized 'geoms' and lazy resolution of node attributes, supporting customization of aesthetics and visual styles. These 'geoms' use a dual-anchor normalization approach to align layers, particularly useful for analyses in which network elements must be spatially aligned with reference maps and images.
| GraphSpace: | Constructor of GraphSpace-class objects. |
| plotGraphSpace: | Wrapper function to plot GraphSpace objects in ggplot2. |
Further information is available in the vignettes by typing
vignette('RGraphSpace'). Documented topics are also available in
HTML by typing help.start() and selecting the RGraphSpace package
from the menu.
Maintainer: Mauro Castro mauro.a.castro@gmail.com (ORCID)
Authors:
Sysbiolab Team
Other contributors:
Flávio Kessler [contributor]
Jonathan Back [contributor]
Lana Querne [contributor]
Victor Apolonio [contributor]
Vinicius Chagas [contributor]
Sysbiolab Team (2026). RGraphSpace: A lightweight interface between 'igraph' and 'ggplot2' graphics. R package version 1.4.0 (Doi: 10.32614/CRAN.package.RGraphSpace), https://CRAN.R-project.org/package=RGraphSpace.
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.