- mapping
Set of aesthetic mappings created by [ggplot2::aes()].
These mappings apply to the layer and may override global aesthetics.
- data
Either a GraphSpace object or a data frame
containing edge attributes. If `NULL`, the layer will use the default
plot data.
- stat
The statistical transformation to use on the data.
Defaults to `"identity"`.
- position
Position adjustment, either as a string or
the result of a call to a position adjustment function.
- ...
Additional parameters passed to the underlying
drawing function in `GeomEdgeSpace`.
- show.legend
Logical or a named logical vector indicating
whether this layer should be included in legends.
- inherit.aes
Logical. If `FALSE` (default), the layer will use
aesthetics defined in `mapping`. Set to `TRUE` if this geom should
inherit aesthetics from the plot.
- lineend
Line end style (round, butt, square).
- linejoin
Line join style (round, mitre, bevel).
- arrow_type
Arrowhead types (see 'drawing' section).
- arrow_size
Numeric scaling factor controlling arrowhead geometry.
- offset_start
Offset arrows as a fraction of graph space at
start positions.
- offset_end
Offset arrows as a fraction of graph space at
end positions.