| plotGraphSpace,GraphSpace-method | R Documentation |
plotGraphSpace() is a High-level plotting interface that translates
igraph and GraphSpace data objects into ggplot2 layers.
## S4 method for signature 'GraphSpace'
plotGraphSpace(
gs,
theme = "th0",
xlab = "Graph coordinates 1",
ylab = "Graph coordinates 2",
font.size = 1,
bg.color = "grey95",
add.labels = FALSE,
node.labels = NULL,
label.size = 3,
label.color = "grey20",
add.image = TRUE,
raster = FALSE,
dpi = 300,
dev = "cairo_png"
)
## S4 method for signature 'igraph'
plotGraphSpace(gs, ...)
## S4 method for signature 'tbl_graph'
plotGraphSpace(gs, ...)
## S4 method for signature 'gs_graph'
plotGraphSpace(gs, ...)
gs |
Either an |
theme |
Name of a custom RGraphSpace theme. These themes
(from 'th0' to 'th3') consist of preconfigured ggplot settings,
which can subsequently refine using |
xlab |
The title for the 'x' axis of a 2D-image space. |
ylab |
The title for the 'y' axis of a 2D-image space. |
font.size |
A single numeric value passed to ggplot themes. |
bg.color |
A single color for background. |
add.labels |
A logical value indicating whether to plot vertex labels. |
node.labels |
A vector of vertex names to be highlighted in the graph space. This argument overrides 'add.labels'. |
label.size |
A size argument passed to |
label.color |
A color passed to |
add.image |
A logical value indicating whether to add a background
image, when one is available (see |
raster |
A logical value indicating whether to rasterize the main plot.
See |
dpi |
Raster resolution, in dots per inch. |
dev |
Device used in the |
... |
Additional arguments passed to the
|
A ggplot-class object.
Sysbiolab.
GraphSpace
library(RGraphSpace)
library(igraph)
# Load a demo igraph
data('gtoy1', package = 'RGraphSpace')
# Generate a ggplot for gtoy1
plotGraphSpace(gtoy1)
# Create a star graph
gtoy_star <- make_full_graph(15)
# Example of setting node and edge attributes
V(gtoy_star)$nodeSize <- 5
E(gtoy_star)$edgeLineColor <- "red"
E(gtoy_star)$arrowType <- "<->"
# Create a GraphSpace object
gs_star <- GraphSpace(gtoy_star)
# Normalize graph coordinates
gs_star <- normalizeGraphSpace(gs_star)
# Generate a ggplot for gs_star
plotGraphSpace(gs_star)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.